@@ -6,9 +6,6 @@
 from __future__ import print_function
 import logging
 import sys
-logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
-                    level=logging.DEBUG,
-                    stream=sys.stdout)
 import os
 import yaml
 try:  # Python 2
