@@ -7,9 +7,6 @@ import inspect
 import imp
 import logging
 import sys
-logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
-                    level=logging.DEBUG,
-                    stream=sys.stdout)
 import os
 import yaml
 import natsort
@@ -19,6 +16,7 @@ import subprocess
 import shutil
 import csv
 import pkg_resources
+import tempfile
 
 # hwrt modules
 from . import HandwrittenData
@@ -409,38 +407,34 @@ def create_adjusted_model_for_percentages(model_src, model_use):
         f.write(content)
 
 
-def create_pfile(output_filename, feature_count, data, input_filename):
+def create_pfile(output_filename, feature_count, data):
     """Create a pfile.
     :param output_filename: name of the pfile that will be created
     :param feature_count: dimension of all features combined
     :type feature_count: int
     :param data: list of (x, y) tuples, where x is the feature vector
                  of dimension ``feature_count`` and y is a label.
-    :param input_filename: path to a file that will be created temporarily
     """
-    # TODO: The input_filename should not be necessary!
-    with open(input_filename, "w") as f:
-        for symbolnr, instance in enumerate(data):
-            feature_string, label = instance
-            assert len(feature_string) == feature_count, \
-                "Expected %i features, got %i features" % \
-                (feature_count, len(feature_string))
-            feature_string = " ".join(map(str, feature_string))
-            line = "%i 0 %s %i" % (symbolnr, feature_string, label)
-            print(line, file=f)
+    f = tempfile.NamedTemporaryFile()
+    input_filename = f.name
+
+    for symbolnr, instance in enumerate(data):
+        feature_string, label = instance
+        assert len(feature_string) == feature_count, \
+            "Expected %i features, got %i features" % \
+            (feature_count, len(feature_string))
+        feature_string = " ".join(map(str, feature_string))
+        line = "%i 0 %s %i" % (symbolnr, feature_string, label)
+        print(line, file=f)
+
     command = "pfile_create -i %s -f %i -l 1 -o %s" % \
               (input_filename, feature_count, output_filename)
     logging.info(command)
     os.system(command)
-    # Clean up
-    os.remove(input_filename)
 
 
-def evaluate_model(recording, model_folder, verbose=False):
-    """Evaluate model for a single recording."""
-    from . import preprocess_dataset
-    from . import features
-
+def get_recognizer_folders(model_folder):
+    """Get a list of folders [preprocessed, feature-files, model]."""
     folders = []
     folder = model_folder
     while os.path.isdir(folder):
@@ -449,9 +443,15 @@ def evaluate_model(recording, model_folder, verbose=False):
         with open(os.path.join(folder, "info.yml")) as ymlfile:
             content = yaml.load(ymlfile)
         folder = os.path.join(get_project_root(), content['data-source'])
-    folders = folders[::-1]  # Reverse order to get the most "basic one first"
+    return folders[::-1]  # Reverse order to get the most "basic one first"
 
-    for target_folder in folders:
+
+def evaluate_model(recording, model_folder, verbose=False):
+    """Evaluate model for a single recording."""
+    from . import preprocess_dataset
+    from . import features
+
+    for target_folder in get_recognizer_folders(model_folder):
         # The source is later than the target. That means we need to
         # refresh the target
         if "preprocessed" in target_folder:
@@ -478,8 +478,9 @@ def evaluate_model(recording, model_folder, verbose=False):
             x = handwriting.feature_extraction(feature_list)
 
             # Create pfile
-            output_filename = "evaluate.pfile"
-            create_pfile(output_filename, feature_count, [(x, 0)], "tmp.txt")
+            output_file_pointer = tempfile.NamedTemporaryFile()
+            output_filename = output_file_pointer.name
+            create_pfile(output_filename, feature_count, [(x, 0)])
         elif "model" in target_folder:
             logging.info("Create running model...")
             model_src = get_latest_model(target_folder, "model")
@@ -510,8 +511,7 @@ def evaluate_model(recording, model_folder, verbose=False):
             return logfile
         else:
             logging.info("'%s' not found", target_folder)
-    # Cleanup
-    os.remove(output_filename)
+    output_file_pointer.close()
 
 
 def classify_single_recording(raw_data_json, model_folder, verbose=False):
